<?php

declare(strict_types=1);

namespace App\Components\Balticrest\Controller;

use App\Components\Balticrest\Service\DTO\PointDTO;
use App\Components\Balticrest\Service\Provider\PointDataProviderInterface;
use App\Components\Balticrest\Service\Provider\ListDataProviderInterface;
use App\Components\Balticrest\Service\Provider\PointTypeProviderInterface;
use App\Components\Balticrest\Service\Schedule\ScheduleDataProviderInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Annotation\Route;

class PointController extends AbstractController
{
    /**
     * @Route(
     *     "/{city}/{category}/list",
     *     requirements={
     *         "city": "svetlogorsk|zelenogradsk",
     *         "category": "hotels|medicine|cafes|shops|banks|museums|sport|transport"
     *     },
     *     methods={"GET"},
     *     name="point_list"
     * )
     *
     * @param Request $request
     * @param PointTypeProviderInterface $pointTypeProvider
     * @param ListDataProviderInterface $listDataProvider
     * @param ScheduleDataProviderInterface $scheduleDataProvider
     *
     * @return Response
     */
    public function pointList(
        Request $request,
        PointTypeProviderInterface $pointTypeProvider,
        ListDataProviderInterface $listDataProvider,
        ScheduleDataProviderInterface $scheduleDataProvider
    ): Response {
        $city = $request->get('city', '');
        $category = $request->get('category', '');

        $data = $listDataProvider->getCachedData($city, $category);

        return $this->render('balticrest/point/list.html.twig', [
            'point_types' => $pointTypeProvider->getCachedListPointTypesList($city),
            'schedule_data' => $scheduleDataProvider->getCachedPointListData($data),
            'list_data' => $data,
        ]);
    }

    /**
     * @Route(
     *     "/{city}/{category}/point/{url}",
     *     requirements={
     *         "city": "svetlogorsk|zelenogradsk",
     *         "category": "hotels|medicine|cafes|shops|banks|museums|sport|transport"
     *     },
     *     methods={"GET"},
     *     name="point"
     * )
     *
     * @param Request $request
     * @param PointDataProviderInterface $pointDataProvider
     * @param ListDataProviderInterface $listDataProvider
     * @param ScheduleDataProviderInterface $scheduleDataProvider
     *
     * @return Response
     */
    public function point(
        Request $request,
        PointDataProviderInterface $pointDataProvider,
        ListDataProviderInterface $listDataProvider,
        ScheduleDataProviderInterface $scheduleDataProvider
    ): Response {
        $url = $request->get('url', '');

        /** @var PointDTO|null $point */
        $point = $pointDataProvider->getCachedPointData($url);

        if ($point === null) {
            throw $this->createNotFoundException();
        }

        return $this->render('balticrest/point/point.html.twig', [
            'point' => $point,
            'similar_points' => $listDataProvider->getCachedSimilarPointsData($point),
            'schedule' => $scheduleDataProvider->getCachedPointData($url)
        ]);
    }
}